@@ -25,19 +25,24 @@ AnnotationDistribution = Dict[str, Counter]
 
 def get_release_path(dataset_path: Path, release_name: Optional[str] = None) -> Path:
     """
-    Given a dataset path and a release name, returns the path to the release
+    Given a dataset path and a release name, returns the path to the release.
 
     Parameters
     ----------
-    dataset_path
-        Path to the location of the dataset on the file system
-    release_name: str
-        Version of the dataset
+    dataset_path : Path
+        Path to the location of the dataset on the file system.
+    release_name : Optional[str], default: None
+        Version of the dataset.
 
     Returns
     -------
-    release_path: Path
-        Path to the location of the dataset release on the file system
+    Path
+        Path to the location of the dataset release on the file system.
+
+    Raises
+    ------
+    NotFound
+        If no dataset is found in the location provided by ``dataset_path``.
     """
     assert dataset_path is not None
 
@@ -56,23 +61,22 @@ def get_release_path(dataset_path: Path, release_name: Optional[str] = None) ->
 
 def extract_classes(annotations_path: Path, annotation_type: str) -> Tuple[Dict[str, Set[int]], Dict[int, Set[str]]]:
     """
-    Given a the GT as json files extracts all classes and an maps images index to classes
+    Given a the GT as json files extracts all classes and an maps images index to classes.
 
     Parameters
     ----------
-    annotations_files: Path
-        Path to the json files with the GT information of each image
+    annotations_files : Path
+        Path to the json files with the GT information of each image.
     annotation_type : str
-        Type of annotation to use to extract the Gt information
+        Type of annotation to use to extract the Gt information.
 
     Returns
     -------
-    classes: dict
-    Dictionary where keys are the classes found in the GT and values
-    are a list of file numbers which contain it
-    indices_to_classes: dict
-    Dictionary where keys are image indices and values are all classes
-    contained in that image
+    Tuple[Dict[str, Set[int]], Dict[int, Set[str]]]
+        A Tuple where the first element is a ``Dictionary`` where keys are the classes found in the
+        GT and values are a list of file numbers which contain it; and the second element is
+        ``Dictionary`` where keys are image indices and values are all classes
+        contained in that image.
     """
 
     assert annotation_type in ["bounding_box", "polygon", "tag"]
@@ -98,12 +102,12 @@ def extract_classes(annotations_path: Path, annotation_type: str) -> Tuple[Dict[
 
 def make_class_lists(release_path: Path) -> None:
     """
-    Support function to extract classes and save the output to file
+    Support function to extract classes and save the output to file.
 
     Parameters
     ----------
-    release_path: Path
-        Path to the location of the dataset on the file system
+    release_path : Path
+        Path to the location of the dataset on the file system.
     """
     assert release_path is not None
     if isinstance(release_path, str):
@@ -131,23 +135,23 @@ def get_classes(
     remove_background: bool = True,
 ) -> List[str]:
     """
-    Given a dataset and an annotation_type returns the list of classes
+    Given a dataset and an annotation_type returns the list of classes.
 
     Parameters
     ----------
-    dataset_path
-        Path to the location of the dataset on the file system
-    release_name: str
-        Version of the dataset
-    annotation_type
-        The type of annotation classes [tag, polygon]
-    remove_background
-        Removes the background class (if exists) from the list of classes
+    dataset_path : PathLike
+        Path to the location of the dataset on the file system.
+    release_name : Optional[str], default: None
+        Version of the dataset.
+    annotation_type : str, default: "polygon"
+        The type of annotation classes [tag, polygon].
+    remove_background : bool, default: True
+        Removes the background class (if exists) from the list of classes.
 
     Returns
     -------
-    classes: list
-        List of classes in the dataset of type classes_type
+    List[str]
+        List of classes in the dataset of type classes_type.
     """
     assert dataset_path is not None
     dataset_path = Path(dataset_path)
@@ -161,36 +165,37 @@ def get_classes(
 
 
 def _f(x: Any) -> Any:
-    """Support function for pool.map() in _exhaust_generator()"""
+    """Support function for ``pool.map()`` in ``_exhaust_generator()``."""
     if callable(x):
         return x()
 
 
 def exhaust_generator(progress: Generator, count: int, multi_threaded: bool) -> List[Dict[str, Any]]:
-    """Exhausts the generator passed as parameter. Can be done multi threaded if desired
+    """
+    Exhausts the generator passed as parameter. Can be done multi threaded if desired.
 
     Parameters
     ----------
     progress : Generator
-        Generator to exhaust
+        Generator to exhaust.
     count : int
-        Size of the generator
+        Size of the generator.
     multi_threaded : bool
-        Flag for multi-threaded enabled operations
+        Flag for multi-threaded enabled operations.
 
     Returns
     -------
-    List[dict]
-        List of responses from the generator execution
+    List[Dict[str, Any]
+        List of responses from the generator execution.
     """
     responses = []
     if multi_threaded:
-        pbar = ProgressBar(total=count)
+        progress_bar: ProgressBar = ProgressBar(total=count)
 
         def update(*a):
-            pbar.completed += 1
+            progress_bar.completed += 1
 
-        with Live(pbar):
+        with Live(progress_bar):
             with mp.Pool(mp.cpu_count()) as pool:
                 for f in progress:
                     responses.append(pool.apply_async(_f, args=(f,), callback=update))
@@ -210,6 +215,38 @@ def get_coco_format_record(
     image_id: Optional[Union[str, int]] = None,
     classes: Optional[List[str]] = None,
 ) -> Dict[str, Any]:
+    """
+    Creates and returns a coco record from the given annotation.
+    Uses ``BoxMode.XYXY_ABS`` from ``detectron2.structures`` if available, defaults to ``box_mode = 0``
+    otherwise.
+
+    Parameters
+    ----------
+    annotation_path : Path
+        ``Path`` to the annotation file.
+    annotation_type : str = "polygon"
+        Type of the annotation we want to retrieve.
+    image_path : Optional[Path], default: None
+        ``Path`` to the image the annotation refers to.
+    image_id : Optional[Union[str, int]], default: None
+        Id of the image the annotation refers to.
+    classes : Optional[List[str]], default: None
+        Classes of the annotation.
+
+    Returns
+    -------
+    Dict[str, Any]
+        A coco record with the following keys:
+
+        .. code-block:: python
+            {
+                "height": 100,
+                "width": 100,
+                "file_name": "a file name",
+                "image_id": 1,
+                "annotations": [ ... ]
+            }
+    """
     assert annotation_type in ["tag", "polygon", "bounding_box"]
     try:
         from detectron2.structures import BoxMode
@@ -272,34 +309,45 @@ def get_annotations(
     ignore_inconsistent_examples: bool = False,
 ) -> Iterator[Dict[str, Any]]:
     """
-    Returns all the annotations of a given dataset and split in a single dictionary
+    Returns all the annotations of a given dataset and split in a single dictionary.
 
     Parameters
     ----------
-    dataset_path
-        Path to the location of the dataset on the file system
-    partition
-        Selects one of the partitions [train, val, test]
-    split
-        Selects the split that defines the percetages used (use 'default' to select the default split)
-    split_type
-        Heuristic used to do the split [random, stratified, None]
-    annotation_type
-        The type of annotation classes [tag, bounding_box, polygon]
-    release_name: str
-        Version of the dataset
-    annotation_format: str
-        Re-formatting of the annotation when loaded [coco, darwin]
-    ignore_inconsistent_examples: bool
+    dataset_path : PathLike
+        Path to the location of the dataset on the file system.
+    partition : Optional[str], default: None
+        Selects one of the partitions ``[train, val, test]``.
+    split : Optional[str], default: "default"
+        Selects the split that defines the percentages used (use 'default' to select the default split).
+    split_type : Optional[str], default: None
+        Heuristic used to do the split ``[random, stratified, None]``.
+    annotation_type : str, default: "polygon"
+        The type of annotation classes ``[tag, bounding_box, polygon]``.
+    release_name : Optional[str], default: None
+        Version of the dataset.
+    annotation_format : Optional[str], default: "coco"
+        Re-formatting of the annotation when loaded ``[coco, darwin]``.
+    ignore_inconsistent_examples : bool, default: False
         Ignore examples for which we have annotations, but either images are missing,
         or more than one images exist for the same annotation.
-        If set to `True`, then filter those examples out of the dataset.
-        If set to `False`, then raise an error as soon as such an example is found.
+        If set to ``True``, then filter those examples out of the dataset.
+        If set to ``False``, then raise an error as soon as such an example is found.
 
     Returns
     -------
-    dict
-        Dictionary containing all the annotations of the dataset
+    Iterator[Dict[str, Any]]
+        Dictionary containing all the annotations of the dataset.
+
+    Raises
+    ------
+    ValueError
+        - If the ``partition`` given is not valid.
+        - If the ``split_type`` given is not valid.
+        - If the ``annotation_type`` given is not valid.
+        - If an annotation has no corresponding image.
+        - If an image is present with multiple extensions.
+    FileNotFoundError
+        If no dataset in ``dataset_path`` is found.
     """
     assert dataset_path is not None
     dataset_path = Path(dataset_path)
@@ -410,14 +458,15 @@ def load_pil_image(path: Path, to_rgb: Optional[bool] = True) -> PILImage.Image:
 
     Parameters
     ----------
-    path: Path
-        Path to the image file
-    to_rgb: bool
-        Converts the image to RGB
+    path : Path
+        Path to the image file.
+    to_rgb : Optional[bool], default: True
+        Converts the image to RGB.
 
     Returns
     -------
-    PIL Image
+    PILImage.Image
+        The loaded image.
     """
     pic = PILImage.open(path)
     if to_rgb:
@@ -427,17 +476,22 @@ def load_pil_image(path: Path, to_rgb: Optional[bool] = True) -> PILImage.Image:
 
 def convert_to_rgb(pic: PILImage.Image) -> PILImage.Image:
     """
-    Converts a PIL image to RGB
+    Converts a PIL image to RGB.
 
     Parameters
     ----------
-    pic: Image
-        PIL Image
+    pic : PILImage.Image
+        The image to convert.
 
     Returns
     -------
     PIL Image
-        Values between 0 and 255
+        Values between 0 and 255.
+
+    Raises
+    ------
+    TypeError
+        If the image given via ``pic`` has an unsupported type.
     """
     if pic.mode == "RGB":
         pass
@@ -462,6 +516,21 @@ def convert_to_rgb(pic: PILImage.Image) -> PILImage.Image:
 
 
 def compute_max_density(annotations_dir: Path) -> int:
+    """
+    Calculates the maximum density of all of the annotations in the given folder.
+    Density is calculated as the number of polygons / complex_polygons present in an annotation
+    file.
+
+    Parameters
+    ----------
+    annotations_dir : Path
+        Directory where the annotations are present.
+
+    Returns
+    -------
+    int
+        The maximum density.
+    """
     max_density = 0
     for annotation_path in annotations_dir.glob("**/*.json"):
         annotation_density = 0
@@ -480,14 +549,31 @@ def compute_distributions(
     annotations_dir: Path,
     split_path: Path,
     partitions: List[str] = ["train", "val", "test"],
-    annotation_types=["polygon"],
+    annotation_types: List[str] = ["polygon"],
 ) -> Dict[str, AnnotationDistribution]:
     """
-    This function builds and returns the following dictionaries:
+    Builds and returns the following dictionaries:
       - class_distribution: count of all files where at least one instance of a given class exists for each partition
       - instance_distribution: count of all instances of a given class exist for each partition
 
     Note that this function can only be used after a dataset has been split with "stratified" strategy.
+
+    Parameters
+    ----------
+    annotations_dir : Path
+        Directory where the annotations are.
+    split_path : Path
+        Path to the split.
+    partitions : List[str], default: ["train", "val", "test"]
+        Partitions to use.
+    annotation_types : List[str], default: ["polygon"]
+        Annotation types to consider.
+
+    Returns
+    -------
+    Dict[str, AnnotationDistribution]
+        - class_distribution: count of all files where at least one instance of a given class exists for each partition
+        - instance_distribution: count of all instances of a given class exist for each partition
     """
 
     class_distribution: AnnotationDistribution = {partition: Counter() for partition in partitions}
@@ -520,7 +606,22 @@ def compute_distributions(
 # https://github.com/python/cpython/blob/main/Lib/pathlib.py#L812
 # TODO implemented here because it's not supported in Pythton < 3.9
 def is_relative_to(path: Path, *other) -> bool:
-    """Return True if the path is relative to another path or False."""
+    """
+    Returns ``True`` if the path is relative to another path or ``False`` otherwise.
+    It also returns ``False`` in the event of an exception, making ``False`` the default value.
+
+    Parameters
+    ----------
+    path : Path
+        The path to evaluate.
+    other : Path
+        The other path to compare against.
+
+    Returns
+    --------
+    bool
+    ``True`` if the path is relative to ``other`` or ``False`` otherwise.
+    """
     try:
         path.relative_to(*other)
         return True
@@ -529,6 +630,19 @@ def is_relative_to(path: Path, *other) -> bool:
 
 
 def sanitize_filename(filename: str) -> str:
+    """
+    Sanitizes the given filename, removing/replacing forbiden characters.
+
+    Parameters
+    ----------
+    filename : str
+        The filename to sanitize.
+
+    Returns
+    -------
+    str
+        The sanitized filename.
+    """
     chars = ["<", ">", '"', "/", "\\", "|", "?", "*"]
 
     if not is_unix_like_os():
