@@ -1,9 +1,10 @@
 import json
-from dataclasses import dataclass
 from functools import partial, reduce
 from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, Set, cast
 
+from jsonschema import validate
+
 from darwin.datatypes import (
     Annotation,
     AnnotationClass,
@@ -16,69 +17,67 @@ from darwin.datatypes import (
     make_polygon,
     make_tag,
 )
+from darwin.importer.formats.labelbox_schemas import labelbox_export
 
 
-def parse_file(path: Path, validate: Callable[[Any], None]) -> Optional[List[AnnotationFile]]:
+def parse_path(path: Path) -> Optional[List[AnnotationFile]]:
     """
     Parses the given LabelBox file and maybe returns the corresponding annotations.
     The file must have a structure simillar to the following:
-    
-    ```json
-    [
-        {
-            "Label":{
-                "objects":[
-                    {
-                        "title": "SomeTitle",
-                        "bbox":{"top":3558, "left":145, "height":623, "width":449}
-                    },
-                    {...}
-                ],
-                "classifications": [
-                    {
-                        "value": "a_question",
-                        "answer": {"value": "an_answer"}
-                    },
-                    ....
-                ]
+
+    .. code-block:: javascript
+        [
+            {
+                "Label":{
+                    "objects":[
+                        {
+                            "title": "SomeTitle",
+                            "bbox":{"top":3558, "left":145, "height":623, "width":449}
+                        },
+                        { }
+                    ],
+                    "classifications": [
+                        {
+                            "value": "a_question",
+                            "answer": {"value": "an_answer"}
+                        }
+                    ]
+                },
+                "External ID": "demo-image-7.jpg"
             },
-            "External ID": "demo-image-7.jpg"
-        },
-        {...}
-    ]
-    ```
+            { }
+        ]
 
     You can check the Labelbox Schemas in `labelbox_schemas.py`.
 
     Currently we support the following annotations:
-    - bounding-box `Image`: https://docs.labelbox.com/docs/bounding-box-json
-    - polygon `Image`: https://docs.labelbox.com/docs/polygon-json
-    - point `Image`: https://docs.labelbox.com/docs/point-json
-    - polyline `Image`: https://docs.labelbox.com/docs/polyline-json
+
+        - bounding-box ``Image``: https://docs.labelbox.com/docs/bounding-box-json
+        - polygon ``Image``: https://docs.labelbox.com/docs/polygon-json
+        - point ``Image``: https://docs.labelbox.com/docs/point-json
+        - polyline ``Image``: https://docs.labelbox.com/docs/polyline-json
 
     We also support conversion from question/answer to Annotation Tags for the following:
-    - Radio Buttons
-    - Checklists
-    - Free Text
+    
+        - Radio Buttons
+        - Checklists
+        - Free Text
 
     Parameters
     --------
     path: Path
         The path of the file to parse.
 
-    validate: Callable[[Any], None]
-        The validator function that validates the schema.
-
     Returns
     -------
     Optional[List[darwin.datatypes.AnnotationFile]]
-        The AnnotationFiles with the parsed information from the file or None, if the file is not a 
+        The AnnotationFiles with the parsed information from the file or None, if the file is not a
         `json` file.
 
     Raises
     ------
     ValidationError
-        If the given JSON file is malformed or if it has an unknown annotation. 
+        If the given JSON file is malformed or if it has an unknown annotation.
         To see a list of possible annotation formats go to:
         https://docs.labelbox.com/docs/annotation-types-1
 
@@ -88,7 +87,7 @@ def parse_file(path: Path, validate: Callable[[Any], None]) -> Optional[List[Ann
 
     with path.open() as f:
         data = json.load(f)
-        validate(data)
+        validate(data, schema=labelbox_export)
         convert_with_path = partial(_convert, path=path)
 
         return _map_list(convert_with_path, data)
